searchNodes=[{"doc":"Inspecto is a utility for inspecting Ecto schemas to view their field names, data types, and default values. Ecto schema modules do not contain full information about your database schemas: they only contain enough information to act as a viable intermediary for the Elixir layer. You cannot, for example, know character length limits or input constraints by merely inspecting Ecto schemas. Although Ecto migrations contain a lot more of this information, they too aren't great for the purpose because migrations are additive with changes spread out over time, and importantly, there's not requirement that a database be defined via migrations. Usage The expected usage of this package is to call Inspecto.summarize/2 from within a @moduledoc tag somewhere inside your app, wherever you wish a summary of your Ecto schemas to appear, e.g. something like this: defmodule MyApp.MyModel do @moduledoc &quot;&quot;&quot; Here is a summary of my Ecto schemas: \#{ MyApp.MyModel |&gt; Inspecto . modules ( ) |&gt; Inspecto . summarize ( format : :html ) } &quot;&quot;&quot; end This will render a series of HTML tables at compile-time. Warning When you call a function from inside a @moduledoc tag, it is evaluated at compile-time . Inspecto should filter out problems and avoid raising errors, but if it generates a problem for any reason, be aware that you may need to remove any calls to its functions from your @moduledoc tags.","ref":"Inspecto.html","title":"Inspecto","type":"module"},{"doc":"This is a convenience function which retrieves a list of modules in the given &quot;namespace&quot;. This is a useful way of gathering up modules that define Ecto schemas. Examples iex&gt; Inspecto . modules ( MyApp ) [ MyApp.Foo , MyApp.Bar , ... ]","ref":"Inspecto.html#modules/1","title":"Inspecto.modules/1","type":"function"},{"doc":"Summarizes the given Ecto schema modules using the format provided. It is necessary to supply a list of modules. Options :format controls the format of the output. Supported values: :html , :raw (default). :h controls the heading level used for each schema ( 3 corresponds to an h3 tag). This is only relevant when :format is set to :html . Default: 2 The :raw format returns information as a list of Inspecto.Schema structs. The :html format returns information as an HTML table. This is suitable for use inside a @moduledoc attribute. Other formats may be supported in the future (e.g. Mermaid JS, but it's not yet compatible with how documentation generation strips out newlines). Examples iex&gt; MyApp.Schemas |&gt; Inspecto . modules ( ) |&gt; Inspecto . summarize ( format : :raw ) [ % Inspecto.Schema { fields : [ % Inspecto.Schema.Field { default : nil , name : :id , type : :binary_id } , % Inspecto.Schema.Field { default : nil , name : :meta , type : :map } , % Inspecto.Schema.Field { default : 30 , name : :net , type : :integer } , # ... ] , module :MyApp . Schemas.SomeSchema , primary_key : [ :id ] , source : &quot;some_table&quot; } ] , # ...","ref":"Inspecto.html#summarize/2","title":"Inspecto.summarize/2","type":"function"},{"doc":"This defines the shape of Ecto schema inspections.","ref":"Inspecto.Schema.html","title":"Inspecto.Schema","type":"module"},{"doc":"Inspects the given Ecto schema module. This will return an :invalid_module tuple if the given module does not define an Ecto schema (this isn't 100% accurate, but it's unlikely that other modules would coincidentally define the same functions as an Ecto schema). Examples iex&gt; Inspecto.Schema . inspect ( MyApp.Schemas.MyThing ) { :ok , % Inspecto.Schema { module : MyApp.Schemas.MyThing , source : &quot;things&quot; , primary_key : [ :id ] , fields : [ % Inspecto.Schema.Field { name : :id , type : :integer , default : nil } , % Inspecto.Schema.Field { name : :name , type : :string , default : &quot;&quot; } , % Inspecto.Schema.Field { name : :created_at , type : :naive_datetime , default : nil } , ] } } iex&gt; Inspecto.Schema . inspect ( Enum ) { :invalid_module , Enum }","ref":"Inspecto.Schema.html#inspect/1","title":"Inspecto.Schema.inspect/1","type":"function"},{"doc":"","ref":"Inspecto.Schema.html#t:t/0","title":"Inspecto.Schema.t/0","type":"type"},{"doc":"Contains info about a specific field.","ref":"Inspecto.Schema.Field.html","title":"Inspecto.Schema.Field","type":"module"},{"doc":"","ref":"Inspecto.Schema.Field.html#t:t/0","title":"Inspecto.Schema.Field.t/0","type":"type"}]